@@ -2,7 +2,7 @@ package WebService::HipChat;
 use Moo;
 with 'WebService::Client';
 
-our $VERSION = '0.1002'; # VERSION
+our $VERSION = '0.2000'; # VERSION
 
 use Carp qw(croak);
 use MIME::Entity;
@@ -180,12 +180,13 @@ sub next {
 }
 
 sub share_file {
-    my ($self, $room, $data) = @_;
-    croak '$room is required' unless $room;
+    my ($self, $destination, $data) = @_;
+    croak '$destination is required' unless $destination;
     croak '$data is required' unless 'HASH' eq ref $data;
 
-    my $path = $self->_url("/room/$room/share/file");
-
+    # Users may be referenced by '@' name OR email address per
+    # https://www.hipchat.com/docs/apiv2/method/share_file_with_user
+    my $api_type  = ( $destination =~ /\@/ ) ? 'user' : 'room';
     my $msg       = $data->{message};
     my $file      = $data->{file};
 
@@ -217,7 +218,7 @@ sub share_file {
 
     $Mime->make_multipart();
 
-    return $self->post("/room/$room/share/file",
+    return $self->post("/$api_type/$destination/share/file",
         $Mime->stringify_body(),
         headers => {
             'content_type' => "multipart/related; boundary=\"$boundary\"",
@@ -240,7 +241,7 @@ WebService::HipChat
 
 =head1 VERSION
 
-version 0.1002
+version 0.2000
 
 =head1 SYNOPSIS
 
@@ -660,7 +661,10 @@ Example response:
 
 =head2 share_file
 
-    $hc->share_file($room, { message => 'msg', file => '/tmp/file.png' });
+    $hc->share_file($destination, { message => 'msg', file => '/tmp/file.png' });
+
+Shares files with $destination, whether that be a room OR a user. If sent to a user, make sure it is their '@' name OR email address. Otherwise we'll think it is a room.
+For example: '@JohnQPublic' OR 'johnq@public.test instead of 'SomeRoom'
 
 =head2 next
 
@@ -682,6 +686,10 @@ Example:
 
 =item *
 
+Andy Baugh <L<https://github.com/troglodyne>>
+
+=item *
+
 Chris C. <L<https://github.com/centreti>>
 
 =item *
